@@ -6,7 +6,7 @@
 package Lingua::Interset::Tagset::MUL::Google;
 use strict;
 use warnings;
-our $VERSION = '2.051';
+our $VERSION = '2.052';
 
 use utf8;
 use open ':utf8';
@@ -45,35 +45,41 @@ around BUILDARGS => sub
     my %dm =
     (
         # punctuation
-        '.'    => ['pos' => 'punc'],
+        '.'     => ['pos' => 'punc'],
         # adjective
-        'ADJ'  => ['pos' => 'adj'],
+        'ADJ'   => ['pos' => 'adj'],
         # adposition (preposition or postposition)
-        'ADP'  => ['pos' => 'adp'],
+        'ADP'   => ['pos' => 'adp'],
         # adverb
-        'ADV'  => ['pos' => 'adv'],
+        'ADV'   => ['pos' => 'adv'],
+        # auxiliary verb (appears in later versions of the tagset, e.g. UDTv2)
+        'AUX'   => ['pos' => 'verb', 'verbtype' => 'aux'],
         # conjunction
-        'CONJ' => ['pos' => 'conj'],
+        'CONJ'  => ['pos' => 'conj'],
         # determiner
-        'DET'  => ['pos' => 'adj', 'prontype' => 'prn'],
+        'DET'   => ['pos' => 'adj', 'prontype' => 'prn'],
         # noun (common and proper)
-        'NOUN' => ['pos' => 'noun'],
+        'NOUN'  => ['pos' => 'noun'],
         # cardinal number
-        'NUM'  => ['pos' => 'num', 'numtype' => 'card'],
+        'NUM'   => ['pos' => 'num', 'numtype' => 'card'],
+        # proper noun (appears in later versions of the tagset, e.g. UDTv2)
+        'PNOUN' => ['pos' => 'noun', 'nountype' => 'prop'],
         # pronoun
-        'PRON' => ['pos' => 'noun', 'prontype' => 'prn'],
+        'PRON'  => ['pos' => 'noun', 'prontype' => 'prn'],
         # particle
-        'PRT'  => ['pos' => 'part'],
+        'PRT'   => ['pos' => 'part'],
         # verb (all tenses and modes)
-        'VERB' => ['pos' => 'verb'],
+        'VERB'  => ['pos' => 'verb'],
         # other: foreign words, typos, abbreviations, interjections
-        'X'    => []
+        'X'     => []
     );
     # Construct encode_map in the form expected by Atom.
     my %em =
     (
-        'pos' => { 'verb' => 'VERB',
-                   'noun' => { 'prontype' => { ''  => 'NOUN',
+        'pos' => { 'verb' => { 'verbtype' => { 'aux' => 'AUX',
+                                               '@'   => 'VERB' }},
+                   'noun' => { 'prontype' => { ''  => { 'nountype' => { 'prop' => 'PNOUN',
+                                                                        '@'    => 'NOUN' }},
                                                '@' => 'PRON' }},
                    'adj'  => { 'adjtype' => { 'pdt' => 'DET',
                                               '@'   => { 'prontype' => { ''  => 'ADJ',
@@ -126,7 +132,7 @@ Lingua::Interset::Tagset::MUL::Google - Driver for the Google Universal Part-of-
 
 =head1 VERSION
 
-version 2.051
+version 2.052
 
 =head1 SYNOPSIS
 
